(assert-no-duplicate-files files)Throw internal error if there are any duplicates in files.
Throw internal error if there are any duplicates in `files`.
(clean-name-version pname pversion)Builds an identifier-safe prefix out of pname and pversion.
Strips every non-alphanumeric character so that names or versions
containing characters like / (e.g. a version of "n/a") don't leak
into the generated package/namespace prefix and break imports.
Builds an identifier-safe prefix out of `pname` and `pversion`. Strips every non-alphanumeric character so that names or versions containing characters like `/` (e.g. a version of "n/a") don't leak into the generated package/namespace prefix and break imports.
(clojure-source-files-relative dirs)(clojure-source-files-relative dirs excl-dir)(determine-source-dirs {:keys [source-paths]
{:keys [included-source-paths]} :mranderson})(duplicated-files files)Returns map of duplicates in files, key is fully qualified file as string, value is num occurrences.
If no duplicates, empty map is returned.
Returns map of duplicates in `files`, key is fully qualified file as string, value is num occurrences. If no duplicates, empty map is returned.
(java-class-dirs srcdeps)lists subdirs of srcdeps which contain .class files
lists subdirs of `srcdeps` which contain .class files
(normalize-dirs dirs)Returns dirs (as strings) normalized, deduped and without subdirs
Returns `dirs` (as strings) normalized, deduped and without subdirs
(srcdeps-relative srcdeps file)Returns the path of file relative to the srcdeps root, using forward
slashes. file is expected to live under srcdeps, as everything produced by
walking the srcdeps tree does.
Returns the path of `file` relative to the `srcdeps` root, using forward slashes. `file` is expected to live under `srcdeps`, as everything produced by walking the srcdeps tree does.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |